compiler

package
v1.3.41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package compiler validates Go source and orchestrates transpilation to SimplicityHL or raw Simplicity bytecode.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Compiler

type Compiler struct {
	// contains filtered or unexported fields
}

Compiler represents the Go to Simplicity compiler

func New

func New(config Config) *Compiler

New creates a new compiler instance

func (*Compiler) Compile

func (c *Compiler) Compile(source, filename string) (string, error)

Compile compiles Go source code to the target format

type Config

type Config struct {
	Target string // "simplicityhl" or "simplicity"
	Debug  bool
}

Config holds compiler configuration

Jump to